package main

import (
	"crypto/x509"
	"encoding/pem"
	"fmt"
	"log"
	"os"
)

func main() {
	if len(os.Args) != 2 {
		log.Fatalf("Usage: %s CERT", os.Args[0])
	}

	pemData, err := os.ReadFile(os.Args[1])
	if err != nil {
		log.Fatalf("failed to read certificate file: %v", err)
	}

	block, _ := pem.Decode(pemData)
	if block == nil || block.Type != "CERTIFICATE" {
		log.Fatal("failed to decode PEM to a certificate")
	}

	cert, err := x509.ParseCertificate(block.Bytes)
	if err != nil {
		log.Fatalf("failed to parse certificate: %v", err)
	}

	fmt.Printf("certificate issuer: %v\n", cert.Issuer)
	fmt.Printf("certificate subject: %v\n", cert.Subject)
	fmt.Printf("certificate DNS names: %v\n", cert.DNSNames)
	fmt.Printf("certificate IP addresses: %v\n", cert.IPAddresses)
	fmt.Printf("certificate public key algorithm: %v\n", cert.PublicKeyAlgorithm)
	fmt.Printf("certificate public key: %v\n", cert.PublicKey)
}
